pub enum LocalInjectedSecretReplicationError {
Source(InjectedSecretError),
Target(InjectedSecretError),
TargetMismatch,
Provision(InjectedSecretProvisionError),
}Expand description
Safe failure while an existing Local foundation capability is projected to one additional workload root during an additive deployment migration.
Variants
Source(InjectedSecretError)
Target(InjectedSecretError)
TargetMismatch
Provision(InjectedSecretProvisionError)